import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {map} from 'lodash';
import {
    Row, Col, Label, FormGroup, UncontrolledTooltip
} from 'reactstrap';
import {small, flexR, noPadding, toolTip, padding, toolTipIcon, smallAlt} from '../common/styles/index';

class File extends Component {
    static propTypes = {
        onChange: PropTypes.func.isRequired,
        name: PropTypes.string.isRequired,
        label: PropTypes.string.isRequired,
        helpText: PropTypes.string,
        disabled: PropTypes.bool,
        error: PropTypes.shape(),
        valuesForUpload: PropTypes.shape()
    };

    static defaultProps = {
        valuesForUpload: null,
        helpText: null,
        error: {
            status: null
        },
        disabled: false,
    };

    constructor() {
        super();
        this.state = {
            pdfBase64: null
        }
    }

    showFile(value){
        if(value.type ==='image/png' || value.type ==='image/jpeg' || value.type ==='image/webp'){
            return(
                <Col sm={2}>
                    <img
                        className="img-fluid"
                        src={URL.createObjectURL(value)} alt="imagen"
                    />
                </Col>
            )
        }

        return(
            <Col sm={2}>
                <p>{value.name}</p>
            </Col>
        )
    }

    render() {
        const {
            name, label, helpText, disabled, error, valuesForUpload
        } = this.props;
        return (
            <FormGroup>
                    {helpText && (
                        <Label
                            style={{...small, ...noPadding, ...flexR, ...padding}}>
                                <p style={{...noPadding, ...toolTipIcon, ...smallAlt}}  id={'ref'+name}>
                                    {String.fromCharCode(0x24D8)}
                                </p>
                        </Label>
                    )}
                <Label className="btn btn-secondary">
                    <p
                        style={noPadding}>
                        {label+" "}
                    </p>
                    <input
                        style={{display: 'none'}}
                        type="file"
                        multiple
                        id={name}
                        name={name}
                        disabled={disabled}
                        onChange={e => this.props.onChange(e)}
                    />
                </Label>
                <p style={{
                    width: '100%',
                    paddingTop: 0.25,
                    fontSize: '80%',
                    color: error.status === 'invalid' ? '#dc3545' : '#43A047'
                }}>
                    {error.message}
                </p>
                {valuesForUpload && (
                    <Row style={{marginLeft: '-15px'}}>
                        {map(valuesForUpload, (value) =>(
                            this.showFile(value)
                        ))}
                    </Row>
                )}
                {helpText && (
                    <UncontrolledTooltip
                        placement="top"
                        target={'ref'+name}
                        style={toolTip}>
                        {helpText}
                    </UncontrolledTooltip>
                )}
            </FormGroup>
        );
    }
}

export default File;
